package sklep.controller;

import java.util.List;
import java.util.Optional;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.ResponseBody;

import sklep.model.Product;
import sklep.repository.ProductRepository;

@Controller
public class ProductController {
    @Autowired
    private ProductRepository productRepository;
    
    @GetMapping(path="/products", produces="text/html")
    public String getProducts(Model model) {
        List<Product> products = productRepository.findAll();
        model.addAttribute("products", products);
        return "products.jsp";
    }
    
    @GetMapping(path="/products/{id}", produces="text/html")
    public String getOneProduct(Model model, @PathVariable("id") Integer id) {
        Optional<Product> optProduct = productRepository.findById(id);
        if(optProduct.isPresent()) {
            model.addAttribute("product", optProduct.get());
            return "/product.jsp";
        } else {
            return "/missing_product.jsp";
        }
    }
    
    @GetMapping(path="/products", produces="text/plain")
    @ResponseBody
    public String getProductsTxt() {
        StringBuilder sb = new StringBuilder("Lista produktów:\n");
        List<Product> products = productRepository.findAll();
        for(Product product : products) {
            sb.append(" * ").append(product.getProductName())
              .append(" za cenę ").append(product.getPrice())
              .append('\n');
        }
        return sb.toString();
    }
}
